@@ -57,7 +57,7 @@ def map_json(mapping_config, json_data, strict=False):
                 if dict == type(list_json):
                     data = list_json.get(config)
                     if data:
-                        list_result.append()
+                        list_result.append(data)
                 else:
                     for lj in list_json:
                         if config in lj:
